%global srcname libjxl
%global sover 0.7
%global gdk_pixbuf_moduledir $(pkgconf gdk-pixbuf-2.0 --variable=gdk_pixbuf_moduledir)

%bcond_with tcmalloc
%bcond_with gimp_plugin

Summary:        JPEG XL image format reference implementation
Name:           jpegxl
Version:        0.7.0
Release:        3%{?dist}
License:        BSD-3-Clause AND Apache-2.0 AND Zlib
URL:            https://jpeg.org/jpegxl/
Source0:        https://github.com/%{srcname}/%{srcname}/archive/v%{version}/%{name}-%{version}.tar.gz #/%{srcname}-%{version}.tar.gz
# git clone https://github.com/libjxl/libjxl
# cd libjxl/
# git checkout v%%{version}
# git submodule init ; git submodule update
# rm -r third_party/brotli/ third_party/googletest/
# rm -r third_party/HEVCSoftware/ third_party/highway/
# rm -r third_party/lcms/ third_party/libpng/
# rm -r third_party/skcms/profiles/ third_party/zlib
# tar -zcvf ../third_party-%%{version}.tar.gz third_party/
Source1:        third_party-%{version}.tar.gz
Patch0001:      https://github.com/libjxl/libjxl/commit/873890998bb151ba54a865cdbd61df22af29774c.patch
Patch0002:      https://github.com/libjxl/libjxl/commit/795b363120bbcfdbb2e2e4fa85146ac6d385137d.patch

BuildRequires:  gcc-c++ cmake asciidoc doxygen ninja-build
BuildRequires:  giflib-devel gtest-devel
BuildRequires:  pkgconfig(zlib) pkgconfig(libhwy)
BuildRequires:  (pkgconfig(glut) or pkgconfig(freeglut))
BuildRequires:  pkgconfig(gflags) pkgconfig(libbrotlicommon)
BuildRequires:  pkgconfig(libjpeg) pkgconfig(libpng) pkgconfig(libwebp)
BuildRequires:  pkgconfig(Qt5) pkgconfig(Qt5X11Extras) pkgconfig(OpenEXR)
%if %{with tcmalloc}
BuildRequires:  gperftools-devel
%endif
%if %{with gimp_plugin}
BuildRequires:  pkgconfig(gimp-2.0)
%endif

Provides:       bundled(sjpeg) = 0-0.1.20210522git868ab55
Provides:       bundled(skcms) = 0-0.1.20210522git6437475

%description
This package contains a reference implementation of JPEG XL (encoder and decoder).


%package     -n libjxl
Summary:        Library files for JPEG-XL
Requires:       shared-mime-info
Recommends:     jxl-pixbuf-loader = %{version}-%{release}
Provides:       jpegxl-libs = %{version}-%{release}

%description -n libjxl
Library files for JPEG-XL.


%package     -n libjxl-devel
Summary:        Development files for JPEG-XL
Requires:       libjxl = %{version}-%{release}
Provides:       jpegxl-devel = %{version}-%{release}

%description -n libjxl-devel
Development files for JPEG-XL.


%package     -n libjxl-utils
Summary:        Utilities for manipulating JPEG XL images
Provides:       jpegxl-utils = %{version}-%{release}
Recommends:     jxl-pixbuf-loader = %{version}-%{release}
Recommends:     gimp-jxl-plugin   = %{version}-%{release}

%description -n libjxl-utils
Utilities for manipulating JPEG XL images.


%package     -n libjxl-devtools
Summary:        Development tools for JPEG-XL
Requires:       libjxl = %{version}-%{release}

%description -n libjxl-devtools
Development tools for JPEG-XL


%package        doc
Summary:        Documentation for JPEG-XL
BuildArch:      noarch

%description    doc
Documentation for JPEG-XL.


%package     -n jxl-pixbuf-loader
Summary:        JPEG-XL image loader for GTK+ applications
BuildRequires:  pkgconfig(gdk-pixbuf-2.0)
Requires:       gdk-pixbuf2

%description -n jxl-pixbuf-loader
Jxl-pixbuf-loader contains a plugin to load JPEG-XL images in GTK+ applications.

%if %{with gimp_plugin}
%package     -n gimp-jxl-plugin
Summary:        A plugin for loading and saving JPEG-XL images
Requires:       gimp

%description -n gimp-jxl-plugin
This is a GIMP plugin for loading and saving JPEG-XL images.
%endif


%prep
%autosetup -p1 -n %{srcname}-%{version}
rm -rf third_party/
%setup -q -T -D -a 1 -n %{srcname}-%{version}


%build
%cmake  -DENABLE_CCACHE=1 \
        -DBUILD_TESTING=OFF \
        -DINSTALL_GTEST:BOOL=OFF \
        -DJPEGXL_ENABLE_BENCHMARK:BOOL=OFF \
        -DJPEGXL_ENABLE_PLUGINS:BOOL=ON \
        -DJPEGXL_FORCE_SYSTEM_BROTLI:BOOL=ON \
        -DJPEGXL_FORCE_SYSTEM_GTEST:BOOL=ON \
        -DJPEGXL_FORCE_SYSTEM_HWY:BOOL=ON \
        -DJPEGXL_WARNINGS_AS_ERRORS:BOOL=OFF \
        -DBUILD_SHARED_LIBS:BOOL=ON \
        -DBUNDLE_LIBPNG_DEFAULT:BOOL=OFF \
        -DBUNDLE_GFLAGS_DEFAULT:BOOL=OFF \
        -DJPEGXL_ENABLE_DEVTOOLS=ON
%cmake_build -- all doc


%install
%cmake_install
rm -v %{buildroot}%{_libdir}/*.a


%files -n libjxl
%license LICENSE
%{_libdir}/libjxl.so.%{sover}*
%{_libdir}/libjxl_threads.so.%{sover}*
%dir %{_datadir}/thumbnailers
%{_datadir}/thumbnailers/jxl.thumbnailer
%{_datadir}/mime/packages/image-jxl.xml


%files -n libjxl-devel
%doc CONTRIBUTING.md
%{_includedir}/jxl/
%{_libdir}/libjxl.so
%{_libdir}/libjxl_threads.so
%{_libdir}/pkgconfig/libjxl.pc
%{_libdir}/pkgconfig/libjxl_threads.pc


%files -n libjxl-utils
%doc CONTRIBUTING.md CONTRIBUTORS README.md
%{_bindir}/cjxl
%{_bindir}/djxl
%{_bindir}/cjpeg_hdr
%{_bindir}/jxlinfo
%{_mandir}/man1/cjxl.1*
%{_mandir}/man1/djxl.1*


%files -n libjxl-devtools
%{_bindir}/fuzzer_corpus
%{_bindir}/butteraugli_main
%{_bindir}/decode_and_encode
%{_bindir}/display_to_hlg
%{_bindir}/exr_to_pq
%{_bindir}/pq_to_hlg
%{_bindir}/render_hlg
%{_bindir}/tone_map
%{_bindir}/texture_to_cube
%{_bindir}/generate_lut_template
%{_bindir}/ssimulacra_main
%{_bindir}/ssimulacra2
%{_bindir}/xyb_range
%{_bindir}/jxl_from_tree


%files doc
%license LICENSE
%doc doc/*.md
%doc %{_vpath_builddir}/html


%files -n jxl-pixbuf-loader
%license LICENSE
%{_libdir}/gdk-pixbuf-2.0/*/loaders/libpixbufloader-jxl.so


%if %{with gimp_plugin}
%files -n gimp-jxl-plugin
%license LICENSE
%{_libdir}/gimp/2.0/plug-ins/file-jxl/
%endif


%changelog
* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.7.0-3
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.7.0-2
- Rebuilt for OpenCloudOS Stream 23.05

* Wed Apr 19 2023 rockerzhu <rockerzhu@tencent.com> - 0.7.0-1
- Initial build
